==> nedi-1.0.7p0.tgz: nedi/html/languages/deutsch/gui.php <==
<?PHP
// German language file  1.0 Remo Rickli
$charset	= "iso-8859-1";

//Verbs usually don't precede nouns
$verb1		= 0;

//Labels
$acslbl		= "Zugriff";
$acklbl		= "Besttigen";
$addlbl		= "Hinzufgen";
$adrlbl		= "Adresse";
$alllbl		= "Alle";
$alrlbl		= "Bereits";
$agelbl		= "Alter";
$altlbl		= "Alternativ";
$arclbl		= "Bogen";
$avalbl		= "Verfuegbarkeit";
$avglbl		= "Durchschnitt";
$buplbl		= "Sichern";
$bwdlbl		= "Bandbreite";
$cfglbl		= "Konfiguration";
$chglbl		= "nderung";
$clalbl		= "Klasse";
$cmblbl		= "Kombination";
$cmdlbl		= "Ausfhren";
$cmplbl		= "Vergleich";
$cmtlbl		= "Kommentar";
$cnclbl		= "Verbindung";
$cndlbl		= "Bedingung";
$conlbl		= "Kontakt";
$coplbl		= "Kopieren";
$cuslbl		= "Spezial";
$dellbl		= "Lschen";
$deplbl		= "Abhngigkeiten";
$deslbl		= "Beschreibung";
$dislbl		= "Aufteilung";
$dsclbl		= "Entdecken";
$duplbl		= "Doppelte";
$durlbl		= "Dauer";
$collbl		= "Spalten";
$dstlbl		= "Destination";
$edilbl		= "Editieren";
$emplbl		= "Leer";
$endlbl		= "Ende";
$errlbl		= "Fehler";
$explbl		= "Exportieren";
$faslbl		= "Schnell";
$fltlbl		= "Filter";
$fillbl		= "Dateien";
$fislbl		= "Zuerst";
$frelbl		= "Frei";
$frmlbl		= "Format";
$fullbl		= "Voll";
$fwdlbl		= "Weiterleiten";
$gralbl		= "Graphen";
$grdlbl		= "Grad";
$grplbl		= "Gruppen";
$hislbl		= "Historie";
$imglbl		= "Bilder";
$implbl		= "Importieren";
$inblbl		= "Eingehend";
$invlbl		= "Inventar";
$isolbl		= "Isoliert";
$laslbl		= "Zuletzt";
$latlbl		= "Latenz";
$lenlbl		= "Lnge";
$levlbl		= "Stufe";
$limlbl		= "Limite";
$loclbl		= "Lokation";
$lodlbl		= "Last";
$loslbl		= "Verloren";
$lstlbl		= "Liste";
$manlbl		= "Haupt";
$maxlbl		= "Maximum";
$mdllbl		= "Modell";
$memlbl		= "Speicher";
$metlbl		= "Metrik";
$msglbl		= "Ereignisse";
$msklbl		= "Maske";
$mgtlbl		= "Verwaltung";
$mullbl		= "Mehrere";
$namlbl		= "Name";
$netlbl		= "Netzwerk";
$neblbl		= "Nachbar";
$newlbl		= "Neu";
$nonlbl		= "Keine";
$nomlbl		= "Nomaden";
$nodlbl		= "Knoten";
$numlbl		= "Anzahl";
$optlbl		= "Optimieren";
$orilbl		= "Original";
$oublbl		= "Ausgehend";
$poplbl		= "Bevlkerung";
$prilbl		= "Prioritt";
$qutlbl		= "Leise";
$rnglbl		= "Bereich";
$realbl		= "Lesen";
$replbl		= "Reparieren ";
$reslbl		= "Zurcksetzen";
$rltlbl		= "Echtzeit";
$rotlbl		= "Drehen";
$seclbl		= "Sicherheit";
$sellbl		= "Auswahl";
$serlbl		= "Serien#";
$sholbl		= "Zeigen";
$shplbl		= "Form";
$sizlbl		= "Grsse";
$slolbl		= "Langsam";
$sndlbl		= "Senden";
$spdlbl		= "Geschwindigkeit";
$srclbl		= "Quelle";
$srtlbl		= "Sortieren";
$srvlbl		= "Dienste";
$stalbl		= "Status";
$strlbl		= "Gerade";
$stslbl		= "Statistik";
$sttlbl		= "Start";
$sumlbl		= "bersicht";
$tgtlbl		= "Ziel";
$timlbl		= "Zeit";
$tmplbl		= "Temperatur";
$totlbl		= "Total";
$trflbl		= "Verkehr";
$typlbl		= "Typ";
$undlbl		= "Unentdeckt";
$updlbl		= "Aktualisieren";
$upllbl		= "Hochladen";
$usrlbl		= "Benutzer";
$vallbl		= "Werte";
$venlbl		= "Hersteller";
$verlbl		= "Version";
$woulbl		= "Ohne";
$wrtlbl		= "Schreiben";
$wtylbl		= "Garantie";

// Meldungen
$nokmsg		= "<h4>Sie sind dafr nicht berechtigt!</h4>\n";
$toumsg		= "<h4>Zeitlimite erreicht oder kein Resultat!</h4>\n";
$lopmsg		= "existiert bereits im Pfad (knnte ein Routing Loop sein)!\n";
$cfmmsg		= "Sind sie sicher?";

// Zeit
$tim['n']	= "Jetzt";
$tim['t']	= "Heute";
$tim['s']	= "Sekunden";
$tim['i']	= "Minuten";
$tim['h']	= "Stunden";
$tim['d']	= "Tage";
$tim['w']	= "Wochen";
$tim['m']	= "Monate";
$tim['y']	= "Jahre";

// Places
$place['r']	= "Region";
$place['c']	= "Stadt";
$place['b']	= "Gebude";
$place['f']	= "Etage";
$place['o']	= "Raum";
$place['a']	= "Rack";

// Groessen
$siz['t']	= "Winzig";
$siz['s']	= "Klein";
$siz['m']	= "Mittel";
$siz['l']	= "Gross";
$siz['x']	= "Extra";

// Meldungsklassen
$mlvl['10']	= "Andere";
$mlvl['50']	= "Info";
$mlvl['100']	= "Notiz";
$mlvl['150']	= "Warnung";
$mlvl['200']	= "Alarm";
$mlvl['250']	= "Notfall";

// Lagerzustand
$stco['10']	= "Neu";
$stco['100']	= "Aktiv";
$stco['150']	= "Gebraucht";
$stco['200']	= "Defekt";

// Incident Gruppen
$igrp['1']	= "Neu";
$igrp['10']	= "Infrastruktur";
$igrp['11']	= "Stromausfall";
$igrp['12']	= "Bauarbeiten";
$igrp['13']	= "Naturgewalten";
$igrp['14']	= "Dienstanbieter";
$igrp['20']	= "Equipment";
$igrp['21']	= "Netzteil";
$igrp['22']	= "Chassis";
$igrp['23']	= "Modul";
$igrp['24']	= "Software";
$igrp['25']	= "Verkehr";
$igrp['30']	= "Menschen";
$igrp['31']	= "Wartung";
$igrp['32']	= "Konfigurationsfehler";
$igrp['33']	= "Kunde";
$igrp['34']	= "Hackerangriff";

?>

==> nedi-1.0.8p11.tgz: nedi/html/languages/deutsch/gui.php <==
<?PHP
// German language file  1.0 Remo Rickli
$charset	= "iso-8859-1";

//Verbs usually don't precede nouns
$verb1		= 0;

//Labels
$acklbl		= "Besttigen";
$acslbl		= "Zugriff";
$actlbl		= "Aktion";
$addlbl		= "Hinzufgen";
$adrlbl		= "Adresse";
$alllbl		= "Alle";
$alrlbl		= "Bereits";
$agelbl		= "Alter";
$altlbl		= "Alternativ";
$arclbl		= "Bogen";
$avalbl		= "Verfuegbarkeit";									# No Umlaut in RRD!
$avglbl		= "Durchschnitt";
$buplbl		= "Sichern";
$bwdlbl		= "Bandbreite";
$cfglbl		= "Konfiguration";
$chglbl		= "nderung";
$clalbl		= "Klasse";
$cmblbl		= "Kombination";
$cmdlbl		= "Ausfhren";
$cmplbl		= "Vergleich";
$cmtlbl		= "Kommentar";
$cnclbl		= "Verbindung";
$cndlbl		= "Bedingung";
$collbl		= "Spalten";
$conlbl		= "Kontakt";
$coplbl		= "Kopieren";
$cuslbl		= "Spezial";
$dcalbl		= "Verwerfen";
$dellbl		= "Lschen";
$deplbl		= "Abhngigkeiten";
$deslbl		= "Beschreibung";
$dislbl		= "Aufteilung";
$dsalbl		= "Inaktiviert";
$dsclbl		= "Entdecken";
$duplbl		= "Doppelte";
$durlbl		= "Dauer";
$drplbl		= "Verwerfen";
$dstlbl		= "Destination";
$edilbl		= "Editieren";
$emplbl		= "Leer";
$endlbl		= "Ende";
$errlbl		= "Fehler";
$explbl		= "Exportieren";
$faslbl		= "Schnell";
$fltlbl		= "Filter";
$fillbl		= "Datei";
$fislbl		= "Zuerst";
$frelbl		= "Frei";
$frmlbl		= "Format";
$fullbl		= "Voll";
$fwdlbl		= "Weiterleiten";
$gralbl		= "Graphen";
$grdlbl		= "Grad";
$grplbl		= "Gruppe";
$hislbl		= "Chronik";
$icelbl		= "Rechnung";
$imglbl		= "Bilder";
$implbl		= "Importieren";
$inblbl		= "Eingehend";
$inclbl		= "Vorfall";
$invlbl		= "Inventar";
$idxlbl		= "Index";
$inflbl		= "Information";
$invlbl		= "Inventar";
$isolbl		= "Isoliert";
$laslbl		= "Zuletzt";
$latlbl		= "Latenz";
$lenlbl		= "Lnge";
$levlbl		= "Stufe";
$limlbl		= "Limite";
$loclbl		= "Lokation";
$lodlbl		= "Last";
$loglbl		= "Protokoll";
$loslbl		= "Verloren";
$lstlbl		= "Liste";
$manlbl		= "Haupt";
$maxlbl		= "Maximum";
$memlbl		= "Speicher";
$metlbl		= "Metrik";
$mdllbl		= "Modell";
$mgtlbl		= "Verwaltung";
$modlbl		= "Modus";
$monlbl		= "berwachen";
$msglbl		= "Ereignisse";
$msklbl		= "Maske";
$mullbl		= "Mehrere";
$namlbl		= "Name";
$netlbl		= "Netzwerk";
$neblbl		= "Nachbar";
$newlbl		= "Neu";
$nodlbl		= "Knoten";
$notlbl		= "Nicht";
$nomlbl		= "Nomaden";
$nonlbl		= "Keine";
$numlbl		= "Anzahl";
$opolbl		= "Optionen";
$optlbl		= "Optimieren";
$orilbl		= "Original";
$oublbl		= "Ausgehend";
$paslbl		= "Passwort";
$poplbl		= "Bevlkerung";
$porlbl		= "Port";
$prolbl		= "Protokoll";
$prilbl		= "Prioritt";
$qutlbl		= "Leise";
$rcvlbl		= "Empfangen";
$realbl		= "Lesen";
$replbl		= "Reparieren ";
$reslbl		= "Zurcksetzen";
$rltlbl		= "Echtzeit";
$rnglbl		= "Bereich";
$rotlbl		= "Drehen";
$rpllbl		= "Ersetzen";
$rptlbl		= "Wiederholen";
$seclbl		= "Sicherheit";
$sellbl		= "Auswahl";
$serlbl		= "Serien#";
$sholbl		= "Zeigen";
$shplbl		= "Form";
$sizlbl		= "Grsse";
$slolbl		= "Langsam";
$sndlbl		= "Senden";
$spdlbl		= "Geschwindigkeit";
$srclbl		= "Quelle";
$srtlbl		= "Sortieren";
$srvlbl		= "Dienste";
$stalbl		= "Zustand";
$strlbl		= "Gerade";
$stslbl		= "Statistik";
$sttlbl		= "Start";
$sumlbl		= "Uebersicht";										# No Umlaut in RRD!
$tgtlbl		= "Ziel";
$timlbl		= "Zeit";
$titlbl		= "Titel";
$tmplbl		= "Temperatur";
$toplbl		= "Top";
$totlbl		= "Total";
$trflbl		= "Verkehr";
$tstlbl		= "Test";
$typlbl		= "Typ";
$undlbl		= "Unentdeckt";
$updlbl		= "Aktualisieren";
$upllbl		= "Hochladen";
$uptlbl		= "Betriebszeit";
$usrlbl		= "Benutzer";
$vallbl		= "Werte";
$venlbl		= "Hersteller";
$verlbl		= "Version";
$woulbl		= "Ohne";
$wrtlbl		= "Schreiben";
$wtylbl		= "Garantie";

// Meldungen
$cfmmsg		= "sind sie sicher?";
$delmsg		= "werden gelscht";
$lopmsg		= "existiert bereits im Pfad (knnte ein Routing Loop sein)!\n";
$nokmsg		= "<h4>Sie sind dafr nicht berechtigt!</h4>\n";
$toumsg		= "<h4>Zeitlimite erreicht oder kein Resultat!</h4>\n";

// Zeit
$tim['n']	= "Jetzt";
$tim['t']	= "Heute";
$tim['s']	= "Sekunden";
$tim['i']	= "Minuten";
$tim['h']	= "Stunden";
$tim['d']	= "Tage";
$tim['w']	= "Wochen";
$tim['m']	= "Monate";
$tim['y']	= "Jahre";

// Places
$place['r']	= "Region";
$place['c']	= "Stadt";
$place['b']	= "Gebude";
$place['f']	= "Etage";
$place['o']	= "Raum";
$place['a']	= "Rack";

// Groessen
$siz['t']	= "Winzig";
$siz['s']	= "Klein";
$siz['m']	= "Mittel";
$siz['l']	= "Gross";
$siz['x']	= "Extra";

// Meldungsklassen
$mlvl['10']	= "Andere";
$mlvl['50']	= "Info";
$mlvl['100']	= "Notiz";
$mlvl['150']	= "Warnung";
$mlvl['200']	= "Alarm";
$mlvl['250']	= "Notfall";

// Lagerzustand
$stco['10']	= "Neu";
$stco['100']	= "Aktiv";
$stco['150']	= "Gebraucht";
$stco['200']	= "Defekt";
$stco['250'] 	= "Unbekannt";

// Incident Gruppen
$igrp['1']	= "Neu";
$igrp['10']	= "Infrastruktur";
$igrp['11']	= "Stromausfall";
$igrp['12']	= "Bauarbeiten";
$igrp['13']	= "Naturgewalten";
$igrp['14']	= "Dienstanbieter";
$igrp['15']	= "Tiere";
$igrp['20']	= "Equipment";
$igrp['21']	= "Netzteil";
$igrp['22']	= "Chassis";
$igrp['23']	= "Modul";
$igrp['24']	= "Software";
$igrp['25']	= "Verkehr";
$igrp['30']	= "Menschen";
$igrp['31']	= "Wartung";
$igrp['32']	= "Konfigurationsfehler";
$igrp['33']	= "Kunde";
$igrp['34']	= "Hackerangriff";

?>
